@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: wlink.py 1776 2017-12-03 12:08:16Z mwall $
+# $Id: wlink.py 1777 2017-12-03 19:33:05Z mwall $
 # Copyright 2014 Matthew Wall
 """weewx driver for WeatherLink web sites
    download data from a weatherlink site for use in weewx
@@ -50,7 +50,7 @@ import weewx
 import weewx.drivers
 
 DRIVER_NAME = "WeatherLink"
-DRIVER_VERSION = "0.12"
+DRIVER_VERSION = "0.13"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -159,7 +159,10 @@ class WeatherLink(weewx.drivers.AbstractDevice):
         while sidx < len(data):
             record = self.unpack_archive_packet(data[sidx:sidx + 52])
             if record['dateTime']:
+                logdbg("yielding: %s" % record)
                 yield record
+            else:
+                logdbg("skipping: %s" % record)
             sidx += 52
 
     def get_data(self, url):
@@ -225,9 +228,6 @@ class WeatherLink(weewx.drivers.AbstractDevice):
             func = _archive_map.get(t)
             if func:
                 packet[t] = func(raw_record[t])
-
-        if packet['windSpeed'] is None or packet['windSpeed'] == 0:
-            packet['windDir'] = None
         packet['interval'] = self.archive_interval / 60
         return packet
 
